#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import gtk

class Preferences(object):
    def __init__(self):
        '''the object that set and store the preferences'''
        self.default_config()
        user_path = os.environ.get('HOME') + '/.strip-comicbook'
        if not os.path.exists(user_path + '/preferences'):
            self.save()
        else:
            self.load()
        
    def default_config(self):
        '''The default preferences'''
        self.imageTypes = ('png', 'jpg', 'jpeg', 'xpm', 'gif', 'tif')
        #~ self.archiveTypes = ('cbr', 'cbz', 'cbt', 'cba', 'cb7', 'rar', 'zip', 'tar', 'ace', '7z', 'gz', 'bz2', 'ar')
        self.archiveTypes = ()
        self.mangaMode = False
        self.view_mode = 0      # 0 = Double page, 1 = Single page, 2 = Fit width
        self.rotated = False
        self.clockwise = True
        self.shadow = True
        self.shadow_image_path = 'ui/page_shadow.png'
        self.is_fullscreen = False
        self.last_file = ''
        self.last_page = 0
        
    def save(self):
        separator = ' '
        current_dir = os.getcwd()
        save_dir = os.environ.get('HOME') + '/.strip-comicbook'
        os.chdir(save_dir)
        file = open('preferences', 'w')
        file.write('manga_mode' + separator + str(int(self.mangaMode)) + '\n')
        file.write('view_mode' + separator + str(int(self.view_mode)) + '\n')
        file.write('rotated' + separator + str(int(self.rotated)) + '\n')
        file.write('clockwise' + separator + str(int(self.clockwise)) + '\n')
        file.write('last_file' + separator + str(self.last_file) + '\n')
        file.write('last_page' + separator + str(self.last_page) + '\n')
        file.close()
        os.chdir(current_dir)
        
    def load(self):
        separator = ' '
        preferences = {}
        current_dir = os.getcwd()
        save_dir = os.environ.get('HOME') + '/.strip-comicbook'
        os.chdir(save_dir)
        file = open('preferences', 'r')
        while 1:
            line = file.readline()
            if line == '':
                break
            else:
                i = 0
                while i < len(line):
                    if line[i] == separator:
                        preferences[line[0 : i]] = line[i + 1 : len(line) - 1]
                    i += 1
        self.mangaMode = bool(int(preferences['manga_mode']))
        self.view_mode = int(preferences['view_mode'])
        self.rotated = bool(int(preferences['rotated']))
        self.clockwise = bool(int(preferences['clockwise']))
        self.last_file = str(preferences['last_file'])
        self.last_page = int(preferences['last_page'])
        if not os.path.exists(self.last_file):
            self.last_file = ''
            self.last_page = 0
        file.close()
        os.chdir(current_dir)
